%define major   4
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

# comment out if not prerel
#define prel     rc1

# Release
%define rel     3

Name:           uhd
Summary:        Universal Hardware Driver for Ettus Research products
Version:        4.8.0.0
Release:        %mkrel %{?prel:0.%prel.}%{rel}
Group:          Communications/Radio
License:        GPLv3+
Url:            http://uhd.ettus.com/
Source0:        https://github.com/EttusResearch/uhd/archive/v%{version}%{?prel:-%prel}/%{name}-%{version}%{?prel:-%prel}.tar.gz
# Bug tracker   https://github.com/EttusResearch/uhd/issues
#
# https://github.com/EttusResearch/uhd/pull/836
Patch:		0001-host-include-cstdint-before-boost-lockfree-queue.hpp.patch
BuildRequires:  cmake
BuildRequires:  boost-devel
BuildRequires:  git
%ifarch %{arm32} %{ix86}
BuildRequires:  libatomic-devel
%endif
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(libgps)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-docutils
BuildRequires:  python3-mako
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-requests
BuildRequires:  python3-ruamel-yaml
BuildRequires:  python3-setuptools
BuildRequires:  doxygen
BuildRequires:  pkgconfig

%description
The UHD is the universal hardware driver for Ettus Research products.
The goal of the UHD is to provide a host driver and API for current and
future Ettus Research products. It can be used standalone without GNU Radio.

%prep
%autosetup -p1 -n %{name}-%{version}%{?prel:-%prel}

%build
%global _vpath_srcdir host
%cmake \
        -DCMAKE_SKIP_RPATH=ON \
        -DENABLE_UTILS=ON \
        -DENABLE_E100=ON \
        -DENABLE_E300=ON \
        -DENABLE_PYTHON_API=ON \
        -DENABLE_PYTHON3=ON \
        -DENABLE_TESTS=OFF \
        -DENABLE_EXAMPLES=OFF \
%ifarch %arm
        -DNEON_SIMD_ENABLE=OFF
%endif
%cmake_build

%install
%cmake_install

# Allow access only to users in usrp group
mkdir -p %{buildroot}%{_udevrulesdir}
mv %{buildroot}%{_libdir}/uhd/utils/uhd-usrp.rules %{buildroot}%{_udevrulesdir}/10-usrp-uhd.rules
sed -i 's/MODE:="0666"/MODE:="0660"/' %{buildroot}%{_udevrulesdir}/10-usrp-uhd.rules

# Remove binaries for tests, examples
rm -rf %{buildroot}%{_libdir}/uhd/{tests,examples}

# Move the utils stuff to libexec dir
mkdir -p %{buildroot}%{_libexecdir}/uhd
mv %{buildroot}%{_libdir}/uhd/utils %{buildroot}%{_libexecdir}/uhd/utils
mv %{buildroot}%{_datadir}/uhd/rfnoc %{buildroot}%{_libexecdir}/uhd/

# Package base docs to base package
mkdir _tmpdoc
mv %{buildroot}%{_docdir}/%{name}/{LICENSE,README.md} _tmpdoc

# Make version sane in uhd.pc
sed -i '/Version/c Version: %{version}' %{buildroot}%{_libdir}/pkgconfig/%{name}.pc

%package -n %{libname}
Summary:        Library files
Group:          Communications/Radio
Requires:       %{name} = %{version}-%{release}

%description -n %{libname}
Library files for the Universal Hardware Driver (UHD).

%package -n %{devname}
Summary:        Development files for UHD
Group:          Communications/Radio
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
Development files for the Universal Hardware Driver (UHD).

%package doc
Summary:        Documentation files for UHD
Group:          Communications/Radio
BuildArch:      noarch

%description doc
Documentation for the Universal Hardware Driver (UHD).

%pre -n uhd
getent group usrp >/dev/null || groupadd -r usrp

%files
%doc _tmpdoc/*
%{_bindir}/*
%{_datadir}/%{name}/cal/*.fbs
%{_datadir}/%{name}/rfnoc-newmod/
%{_udevrulesdir}/10-usrp-uhd.rules
%{_libexecdir}/%{name}
%{python3_sitearch}/%{name}/
%{python3_sitearch}/usrp_mpm/

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/*
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/*.pc
%{_libdir}/cmake/%{name}/

%files doc
%doc %{_docdir}/%{name}/
%{_mandir}/man1/*


%changelog
* Sat Mar 08 2025 daviddavid <daviddavid> 4.8.0.0-3.mga10
+ Revision: 2161921
- rebuild for python 3.13

* Tue Feb 11 2025 wally <wally> 4.8.0.0-2.mga10
+ Revision: 2146822
- BR libatomic-devel on 32 bit arches
- rebuild for boost 1.87.0

* Mon Feb 03 2025 barjac <barjac> 4.8.0.0-1.mga10
+ Revision: 2144963
- new version 4.8.0.0
- add new files to list

* Fri Sep 13 2024 wally <wally> 4.7.0.0-2.mga10
+ Revision: 2095532
- rebuild for boost 1.86.0

* Thu Aug 22 2024 barjac <barjac> 4.7.0.0-1.mga10
+ Revision: 2087746
- new version 4.7.0
- remove obsolete patches
- remove python temporary fixes related to python 2 to 3 updgrade

* Wed Jun 19 2024 wally <wally> 4.6.0.0-3.mga10
+ Revision: 2075535
- rebuild for boost 1.85.0

* Fri Jan 12 2024 wally <wally> 4.6.0.0-2.mga10
+ Revision: 2030605
- rebuild for boost 1.84.0

* Wed Dec 20 2023 joequant <joequant> 4.6.0.0-1.mga10
+ Revision: 2020486
- update to 4.6.0.0

* Wed Sep 27 2023 wally <wally> 4.4.0.0-2.mga10
+ Revision: 1991509
- rebuild for boost 1.83.0

* Tue Jan 31 2023 barjac <barjac> 4.4.0.0-1.mga9
+ Revision: 1937144
- new version 4.4.0.0

* Sat Dec 24 2022 wally <wally> 4.3.0.0-2.mga9
+ Revision: 1926537
- rebuild for boost 1.81.0

* Fri Sep 16 2022 barjac <barjac> 4.3.0.0-1.mga9
+ Revision: 1889209
- new version 4.3.0.0

* Wed Aug 03 2022 barjac <barjac> 4.2.0.1-1.mga9
+ Revision: 1874777
- new version 4.2.0.1

* Sun Jul 03 2022 wally <wally> 4.2.0.0-2.mga9
+ Revision: 1867318
- rebuild for boost 1.79.0

* Fri Apr 22 2022 barjac <barjac> 4.2.0.0-1.mga9
+ Revision: 1852641
- new version 4.2.0.0
- new BR python3-ruamel-yaml

* Tue Apr 05 2022 umeabot <umeabot> 4.1.0.5-3.mga9
+ Revision: 1844134
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 tmb <tmb> 4.1.0.5-2.mga9
+ Revision: 1774882
- rebuild for python 3.10

* Tue Feb 01 2022 barjac <barjac> 4.1.0.5-1.mga9
+ Revision: 1770857
- new version 4.1.0.5
- remove obsolete patch

* Thu Dec 23 2021 wally <wally> 4.1.0.2-2.mga9
+ Revision: 1763465
- add patch to fix str fmt
- rebuild for boost 1.78.0

* Sun Sep 19 2021 barjac <barjac> 4.1.0.2-1.mga9
+ Revision: 1745932
- new version 4.1.0.2

* Sun Sep 19 2021 barjac <barjac> 4.1.0.1-1.mga9
+ Revision: 1745895
- new version 4.1.0.1
- remove un-needed patches
- minor spec tidy

* Thu Sep 09 2021 wally <wally> 4.0.0.0-7.mga9
+ Revision: 1744694
- skip RPATH while building and installing
- rebuild for boost 1.77.0

* Sat May 15 2021 wally <wally> 4.0.0.0-6.mga9
+ Revision: 1723371
- rebuild for boost 1.76.0

* Tue Mar 23 2021 barjac <barjac> 4.0.0.0-5.mga9
+ Revision: 1708028
- rebuild for python-3.9

* Thu Dec 31 2020 wally <wally> 4.0.0.0-4.mga8
+ Revision: 1666826
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 4.0.0.0-3.mga8
+ Revision: 1662068
- rebuild for boost 1.74.0

* Sat Oct 03 2020 wally <wally> 4.0.0.0-2.mga8
+ Revision: 1631984
- fix linking with python

* Sat Oct 03 2020 barjac <barjac> 4.0.0.0-1.mga8
+ Revision: 1631907
- new version 4.0.0.0
- new major 4
- upstream python components patch
- update files list
- disable_ld_no_undefined
- upstream fix for CMakeLists.txt

* Sun May 03 2020 wally <wally> 3.15.0.0-4.mga8
+ Revision: 1578511
- rebuild for boost 1.73.0

* Wed Feb 19 2020 umeabot <umeabot> 3.15.0.0-3.mga8
+ Revision: 1544936
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 3.15.0.0-2.mga8
+ Revision: 1483445
- rebuild for boost 1.72.0

* Sat Jan 04 2020 barjac <barjac> 3.15.0.0-1.mga8
+ Revision: 1476039
- new version 3.15.0.0
- Remove old obsoletes/conflicts
- Use wildcard to simplify files list
+ wally <wally>
- build with new cmake macros

* Sun Sep 15 2019 wally <wally> 3.14.1.1-0.rc1.1.mga8
+ Revision: 1441620
- new version 3.14.1.1
+ tv <tv>
- rebuild for python-3.8

* Wed Sep 11 2019 barjac <barjac> 3.14.1.0-1.mga8
+ Revision: 1439521
- new version 3.14.1.0
- switch to python3

* Thu Apr 18 2019 barjac <barjac> 3.14.0.0-1.mga7
+ Revision: 1393227
- new version 3.14.0.0
- add build switches
- adjust files lists
- adjust build requires

* Fri Jan 18 2019 barjac <barjac> 3.13.1.0-2.mga7
+ Revision: 1357881
- try to fix arm build

* Wed Jan 16 2019 barjac <barjac> 3.13.1.0-1.mga7
+ Revision: 1357497
- new version 3.13.1
- Remove neon patch fixed upstream

* Tue Oct 16 2018 wally <wally> 3.12.0.0-3.mga7
+ Revision: 1321107
- rebuild for new boost 1.68.0

* Sun Sep 23 2018 umeabot <umeabot> 3.12.0.0-2.mga7
+ Revision: 1301507
- Mageia 7 Mass Rebuild

* Mon Jun 25 2018 barjac <barjac> 3.12.0.0-1.mga7
+ Revision: 1239719
- new version 3.12.0.0
- drop boost-1.66 patch as fixed upstream
- use proper upstream tarball to fix Url
- use autosetup
- fix files list

* Tue Dec 26 2017 wally <wally> 3.10.2.0-5.mga7
+ Revision: 1185427
- add upstream patch to fix build with boost 1.66

* Tue Nov 21 2017 tv <tv> 3.10.2.0-4.mga7
+ Revision: 1178072
- rebuild for boost 1.65

* Fri Oct 13 2017 barjac <barjac> 3.10.2.0-3.mga7
+ Revision: 1171607
- replace invalid Version string in uhd.pc which breaks pkgconfig() provide

* Thu Oct 12 2017 barjac <barjac> 3.10.2.0-2.mga7
+ Revision: 1171101
- try to fix arm build with debian patch
- escape commented macros

* Wed Oct 11 2017 barjac <barjac> 3.10.2.0-1.mga7
+ Revision: 1171091
- new version 3.10.2.0

* Sun Sep 17 2017 tv <tv> 3.10.1.1-2.mga7
+ Revision: 1154962
- rebuild with latest boost

* Wed Feb 15 2017 barjac <barjac> 3.10.1.1-1.mga6
+ Revision: 1086302
- new version 3.10.1.1
- moved lib into separate package using %%mklibname
- changed to handle upstream file structure changes
- fixed upstream tarball and directory naming
- sorted conflicts/obsoletes for moved/renamed packages

* Tue Sep 06 2016 barjac <barjac> 3.9.5-1.mga6
+ Revision: 1050270
- new version 3.9.5
- spec tidy

* Tue May 10 2016 barjac <barjac> 3.9.4-1.mga6
+ Revision: 1011827
- new version 3.9.4

* Thu Mar 24 2016 barjac <barjac> 3.9.3-1.mga6
+ Revision: 994694
- new version 3.9.3

* Thu Dec 31 2015 barjac <barjac> 3.9.2-1.mga6
+ Revision: 917030
- new version 3.9.2

* Thu Dec 24 2015 barjac <barjac> 3.9.1-2.mga6
+ Revision: 914236
- rebuild for boost-1.60.0

* Thu Dec 10 2015 barjac <barjac> 3.9.1-1.mga6
+ Revision: 909266
- new version 3.9.1
- fix %%files
- clean spec

* Thu Sep 24 2015 barjac <barjac> 3.8.5-3.mga6
+ Revision: 883361
- rebuild for boost-1.59

* Mon Aug 24 2015 barjac <barjac> 3.8.5-2.mga6
+ Revision: 868934
- rebuild for boost-1.58

* Wed Aug 12 2015 fwang <fwang> 3.8.5-1.mga6
+ Revision: 863478
- update file list
- 3.8.5
+ daviddavid <daviddavid>
- rebuild for new boost-1.58.0

* Wed Oct 15 2014 umeabot <umeabot> 3.7.2-3.mga5
+ Revision: 747090
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.7.2-2.mga5
+ Revision: 690028
- Mageia 5 Mass Rebuild

* Tue Sep 02 2014 barjac <barjac> 3.7.2-1.mga5
+ Revision: 671062
- new version 3.7.2

* Mon Jun 09 2014 barjac <barjac> 3.7.1-1.mga5
+ Revision: 634933
- new version 3.7.1
- fix files list

* Mon Feb 10 2014 barjac <barjac> 3.6.2-1.mga5
+ Revision: 588137
- new version 3.6.2
- changed vcs repo url
- fix broken path since 3.6.0
- fix file list

* Sat Oct 19 2013 umeabot <umeabot> 3.5.3-3.mga5
+ Revision: 529658
- Mageia 4 Mass Rebuild

* Thu Jul 11 2013 fwang <fwang> 3.5.3-2.mga4
+ Revision: 452819
- rebuild for new boost

* Fri May 31 2013 barjac <barjac> 3.5.3-1.mga4
+ Revision: 433512
- new version 3.5.3

* Wed Apr 10 2013 barjac <barjac> 3.5.1-2.mga3
+ Revision: 409431
- rebuild for boost-1.53

* Fri Feb 01 2013 barjac <barjac> 3.5.1-1.mga3
+ Revision: 393856
- new version 3.5.1

* Mon Jan 14 2013 fwang <fwang> 3.5.0-2.mga3
+ Revision: 385731
- update udev rules dir
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 07 2013 barjac <barjac> 3.5.0-1.mga3
+ Revision: 341382
- new version 3.5.0

* Thu Dec 20 2012 fwang <fwang> 3.4.3-3.mga3
+ Revision: 333112
- rebuild for new boost

* Fri Sep 28 2012 barjac <barjac> 3.4.3-2.mga3
+ Revision: 299080
- Changed group to new policy

* Sat Sep 22 2012 barjac <barjac> 3.4.3-1.mga3
+ Revision: 296773
- New version 3.4.3

* Tue Jul 31 2012 fwang <fwang> 3.4.2-2.mga3
+ Revision: 276501
- rebuild for new boost

* Sat Jun 09 2012 barjac <barjac> 3.4.2-1.mga3
+ Revision: 258969
- New version 3.4.2
- changed BR libusb1.0-devel
- Minor edit to make-tarball script

* Wed May 30 2012 fwang <fwang> 3.4.1-2.mga3
+ Revision: 249873
- disable check
- drop unused command
- rebuild for new boost

* Sat Apr 21 2012 barjac <barjac> 3.4.1-1.mga2
+ Revision: 232342
- new version

* Sat Mar 03 2012 barjac <barjac> 3.3.2-1.mga2
+ Revision: 217237
- new version 3.3.2
- added make-tarball script for simpler updates

* Sat Jan 14 2012 barjac <barjac> 3.3.1-1.mga2
+ Revision: 196168
- Corrected Group in sub packages
- Cleaned
- Added BR orc
- Removed %%post, %%postun ldconfig
- Changed Group tag
- imported package uhd


* Fri Dec  2 2011 Jaroslav Škarvada <jskarvad@redhat.com> - 3.3.1-1
- New version

* Thu Dec  1 2011 Jaroslav Škarvada <jskarvad@redhat.com> - 3.3.0-3
- Updated summary to be more descriptive

* Wed Nov 30 2011 Jaroslav Škarvada <jskarvad@redhat.com> - 3.3.0-2
- Fixed according to reviewer comments

* Tue Nov 01 2011 Jaroslav Škarvada <jskarvad@redhat.com> - 3.3.0-1
- Initial version
